@@ -167,6 +167,21 @@ func (c *Config) flagSetOpenVPN(flagSet *flag.FlagSet) {
 		lookupEnvOrDefault("openvpn.client-config.token-claim", c.OpenVPN.ClientConfig.TokenClaim),
 		"If non-empty, the value of the token claim is used to lookup the configuration file in the CCD directory. If empty, the common name is used.",
 	)
+	flagSet.BoolVar(
+		&c.OpenVPN.ClientConfig.UserSelector.Enabled,
+		"openvpn.client-config.user-selector.enabled",
+		lookupEnvOrDefault("openvpn.client-config.user-selector.enabled", c.OpenVPN.ClientConfig.UserSelector.Enabled),
+		"If true, openvpn-auth-oauth2 will display a profile selection UI after OAuth2 authentication, allowing users to choose their client configuration profile. "+
+			"Profile options are populated from openvpn.client-config.user-selector.static-values and openvpn.client-config.token-claim (if configured). "+
+			"After selection, the chosen profile name is used to lookup the configuration file in the CCD directory.",
+	)
+	flagSet.TextVar(
+		&c.OpenVPN.ClientConfig.UserSelector.StaticValues,
+		"openvpn.client-config.user-selector.static-values",
+		lookupEnvOrDefault("openvpn.client-config.user-selector.static-values", c.OpenVPN.ClientConfig.UserSelector.StaticValues),
+		"Comma-separated list of static profile names that are always available in the profile selector UI. "+
+			"These profiles will be displayed as selectable options for all users.",
+	)
 	flagSet.StringVar(
 		&c.OpenVPN.CommonName.EnvironmentVariableName,
 		"openvpn.common-name.environment-variable-name",
@@ -392,13 +407,13 @@ func (c *Config) flagSetOAuth2(flagSet *flag.FlagSet) {
 		&c.OAuth2.Validate.IPAddr,
 		"oauth2.validate.ipaddr",
 		lookupEnvOrDefault("oauth2.validate.ipaddr", c.OAuth2.Validate.IPAddr),
-		"validate client ipaddr between VPN and oidc token",
+		"validate client ipaddr between VPN and OIDC token",
 	)
 	flagSet.BoolVar(
 		&c.OAuth2.Validate.Issuer,
 		"oauth2.validate.issuer",
 		lookupEnvOrDefault("oauth2.validate.issuer", c.OAuth2.Validate.Issuer),
-		"validate issuer from oidc discovery",
+		"validate issuer from OIDC discovery",
 	)
 	flagSet.StringVar(
 		&c.OAuth2.Validate.CommonName,
@@ -412,6 +427,14 @@ func (c *Config) flagSetOAuth2(flagSet *flag.FlagSet) {
 		lookupEnvOrDefault("oauth2.validate.common-name-case-sensitive", c.OAuth2.Validate.CommonNameCaseSensitive),
 		"If true, openvpn-auth-oauth2 will validate the common case in sensitive mode",
 	)
+	flagSet.StringVar(
+		&c.OAuth2.Validate.CEL,
+		"oauth2.validate.cel",
+		lookupEnvOrDefault("oauth2.validate.cel", c.OAuth2.Validate.CEL),
+		"CEL expression for custom token validation. "+
+			"The expression must evaluate to a boolean value. "+
+			"Example: openVPNUserCommonName == oauth2TokenClaims.preferred_username",
+	)
 	flagSet.TextVar(
 		&c.OAuth2.Scopes,
 		"oauth2.scopes",
@@ -419,4 +442,19 @@ func (c *Config) flagSetOAuth2(flagSet *flag.FlagSet) {
 		"oauth2 token scopes. Defaults depends on oauth2.provider. Comma separated list. "+
 			"Example: openid,profile,email",
 	)
+
+	flagSet.StringVar(
+		&c.OAuth2.OpenVPNUsernameClaim,
+		"oauth2.openvpn-username-claim",
+		lookupEnvOrDefault("oauth2.openvpn-username-claim", c.OAuth2.OpenVPNUsernameClaim),
+		"The claim name in the ID Token which should be used as username in OpenVPN. If empty, the common name is used.",
+	)
+	flagSet.StringVar(
+		&c.OAuth2.OpenVPNUsernameCEL,
+		"oauth2.openvpn-username-cel",
+		lookupEnvOrDefault("oauth2.openvpn-username-cel", c.OAuth2.OpenVPNUsernameCEL),
+		"CEL expression to extract the username from the token. The expression must evaluate to a string value. "+
+			"Example: oauth2TokenClaims.sub "+
+			"Note: oauth2.openvpn-username-claim and oauth2.openvpn-username-cel cannot be set at the same time.",
+	)
 }
