@@ -4,6 +4,7 @@ import (
 	"context"
 	"log/slog"
 
+	"github.com/google/cel-go/cel"
 	types2 "github.com/jkroepke/openvpn-auth-oauth2/internal/config"
 	"github.com/jkroepke/openvpn-auth-oauth2/internal/oauth2/idtoken"
 	"github.com/jkroepke/openvpn-auth-oauth2/internal/oauth2/types"
@@ -17,6 +18,7 @@ type Client struct {
 	openvpn         openvpnManagementClient
 	storage         tokenstorage.Storage
 	provider        Provider
+	celEvalPrg      cel.Program
 	logger          *slog.Logger
 	authorizeParams []rp.URLParamOpt
 	conf            types2.Config
@@ -33,3 +35,10 @@ type Provider interface {
 	Refresh(ctx context.Context, logger *slog.Logger, relyingParty rp.RelyingParty, refreshToken string) (idtoken.IDToken, error)
 	RevokeRefreshToken(ctx context.Context, logger *slog.Logger, relyingParty rp.RelyingParty, refreshToken string) error
 }
+
+// clientConfigToken is used to store additional information on the client side.
+type clientConfigToken struct {
+	Username string   `json:"username,omitempty"`
+	State    string   `json:"state,omitempty"`
+	Profiles []string `json:"profiles,omitempty"`
+}
