@@ -1,3 +1,5 @@
+//go:build linux && cgo
+
 package util
 
 import "C"
@@ -23,7 +25,7 @@ func ArgvToStrings(argv **c.Char) []string {
 
 	// Count
 	count := 0
-	for p := argv; *p != nil; p = (**c.Char)(unsafe.Pointer(uintptr(unsafe.Pointer(p)) + unsafe.Sizeof(*p))) {
+	for p := argv; *p != nil; p = (**c.Char)(unsafe.Add(unsafe.Pointer(p), unsafe.Sizeof(*p))) {
 		count++
 	}
 
